# Pedigree Generation Package

PedGen is a python package that can be used to generate genetically realistic pedigrees. Generated pedigrees can be visualized as directed acyclic graphs and exported in PED file format.

## Prerequisites

Some functionality included in PedGen relies on system-level dependencies, namely in instalation of Graphviz. Please ensure Graphviz is installed before using the pedigree visualization functionality:

**Unix**
```bash
sudo apt install graphviz libgraphviz-dev
```

**macOS(Homebrew)**
```bash
brew install graphviz
```

## Installation

All required Python dependencies will be installed automatically with this package using pip.

```bash
pip install PedGen
```

## Usage


## License

[MIT]
(https://choosealicense.com/licenses/mit/)